pitchtools.is_named_chromatic_pitch_token
=========================================

.. autofunction:: abjad.tools.pitchtools.is_named_chromatic_pitch_token.is_named_chromatic_pitch_token
   :noindex:
